@@ -1,8 +1,10 @@
 #!/usr/bin/env python
 """Local and remote asteroid name resolution."""
 import asyncio
+import pickle
 import re
 import warnings
+import sys
 
 import aiohttp
 import nest_asyncio
@@ -61,7 +63,7 @@ def identify(id_, return_id=False, local=True, progress=False):
     elif not isinstance(id_, (list, np.ndarray)):
         raise TypeError(
             f"Received id_ of type {type(id_)}, expected one of: "
-            f"str, int, float, list, set, range, np.ndarray, pd.Series"
+            "str, int, float, list, set, range, np.ndarray, pd.Series"
         )
 
     if not id_:
@@ -162,7 +164,7 @@ def _local_lookup(id_):
 
     # Reduce ID and retrieve fitting index
     id_ = _reduce_id_for_local(id_)
-    INDEX = rocks.utils.get_index_file(id_)
+    INDEX = rocks.index.get_index_file(id_)
 
     if id_ in INDEX:
         # Is the number included?
@@ -278,7 +280,7 @@ def _standardize_id_for_quaero(id_):
     else:
         warnings.warn(
             f"Did not understand type of id: {type(id_)}"
-            f"\nShould be integer, float, or string."
+            "\nShould be integer, float, or string."
         )
     return id_
 
@@ -303,9 +305,9 @@ async def _query_quaero(id_, session):
     url = "https://api.ssodnet.imcce.fr/quaero/1/sso/search"
 
     params = {
-        "q": f'type:("Dwarf Planet" OR Asteroid)' f' AND "{id_}"~0',
+        "q": f'type:("Dwarf Planet" OR Asteroid) AND "{id_}"~0',
         "from": "rocks",
-        "limit": 10000,
+        "limit": 100,
     }
 
     response = await session.request(method="GET", url=url, params=params)
@@ -344,14 +346,14 @@ def _parse_quaero_response(data, id_):
         SsODNet and np.nan for the number.
     """
 
-    id_ = str(id_).lower()
+    id_ = str(id_)
 
     for match in data:
-        if match["name"].lower() == id_:
+        if match["name"] == id_:
             break
-        elif match["id"].lower() == id_:
+        elif match["id"] == id_:
             break
-        elif any([alias.lower() == id_ for alias in match["aliases"]]):
+        elif any(alias == id_ for alias in match["aliases"]):
             break
     else:
         # Unclear which match is correct.
@@ -362,3 +364,22 @@ def _parse_quaero_response(data, id_):
     numeric = [int(alias) for alias in match["aliases"] if alias.isnumeric()]
     number = min(numeric) if numeric else np.nan
     return (match["name"], number, match["id"])
+
+
+def _interactive():
+    """Launch interactive, fuzzy-searchable selection of asteroid.
+
+    Returns
+    -------
+    str
+        The name of the selected asteroid.
+    """
+
+    with open(rocks.PATH_INDEX / "fuzzy_index.pkl", "rb") as file_:
+        LINES = pickle.load(file_)
+
+    # Launch selection
+    choice = rocks.cli._interactive(LINES)
+
+    # Return asteroid name
+    return " ".join(choice.split()[1:])
