@@ -1,12 +1,14 @@
 #!/usr/bin/env python
 """Utility functions for rocks."""
 
+from bs4 import BeautifulSoup
 from functools import reduce
 import json
 import re
 import shutil
 import string
 import tarfile
+import urllib
 import warnings
 
 import numpy as np
@@ -168,8 +170,6 @@ def cache_inventory():
         The SsODNet IDs and versions of the cached ssoCards.
     list of tuple
         The SsODNet IDs and names of the cached datacloud catalogues.
-    list of str
-        The cached metadata files.
     """
 
     # Get all JSONs in cache
@@ -181,7 +181,7 @@ def cache_inventory():
     for file_ in cached_jsons:
 
         # Is it metadata?
-        if file_ == str(rocks.PATH_MAPPING):
+        if file_ == rocks.PATH_MAPPING:
             continue
 
         # Datacloud catalogue or ssoCard?
@@ -211,14 +211,12 @@ def cache_inventory():
         else:
             cached_cards.append(ssodnet_id)
 
-    # Get cached metadata files
-    cached_meta = [rocks.PATH_MAPPING.stem] if rocks.PATH_MAPPING.is_file() else []
-    return cached_cards, cached_catalogues, cached_meta
+    return cached_cards, cached_catalogues
 
 
 def clear_cache():
-    """Remove the cached ssoCards, datacloud catalogues, and metadata files."""
-    cards, catalogues, _ = cache_inventory()
+    """Remove the cached ssoCards and datacloud catalogues."""
+    cards, catalogues = cache_inventory()
 
     for card in cards:
         PATH_CARD = rocks.PATH_CACHE / f"{card}.json"
@@ -401,3 +399,32 @@ def cache_all_ssocards():
 
         member.path = member.path.split("/")[-1]
         cards.extract(member, rocks.PATH_CACHE)
+
+
+def get_citation_from_mpc(name):
+    """Query asteroid information from MPC and extract citation from HTML response."""
+
+    URL = f"https://minorplanetcenter.net/db_search/show_object?object_id={urllib.parse.quote_plus(str(name))}"
+
+    soup = BeautifulSoup(requests.get(URL).text, "html.parser")
+
+    citation = soup.find("div", {"id": "citation"})
+
+    if citation is None:
+        return None
+
+    # Extract citation and do minor formatting
+    citation = citation.find("br").next_sibling.next_sibling
+    citation = citation.split("[")[0].strip().replace("  ", " ")
+    return citation
+
+    # contents = [content for content in citation.contents if not content.tag]
+
+    # alias, *_, citation, ref, ref_number = citation.contents
+
+    # alias = alias.strip()
+    # citation = citation.replace("[Ref:", "").replace("  ", " ").strip()
+    # ref_number = ref_number.replace("]", "").strip()
+    # ref = ref.text
+
+    # return alias, citation, " ".join([ref, ref_number])
